@@ -1,7 +1,8 @@
 class ClassOptionsOptions:
-    def __init__(self, primary:bool, deprecated:bool):
+    def __init__(self, primary:bool, deprecated:bool, implicit: bool):
         self.primary = primary
         self.deprecated = deprecated
+        self.implicit = implicit
 
 
 class ClassOptions:
@@ -9,8 +10,11 @@ class ClassOptions:
     def __init__(self, options: ClassOptionsOptions):
         self.options = options
 
-    def isPrimary(self):
+    def is_primary(self):
         return self.options.primary
 
-    def isDeprecated(self):
+    def is_deprecated(self):
         return self.options.deprecated
+
+    def is_implicit(self):
+        return self.options.implicit
\ No newline at end of file
